@@ -51,6 +51,20 @@ class ProtoTest():
             self.method_name = ''
 
 
+    @property
+    def dotted_name(self, ignored=None):
+        return self.module + '.' + self.class_name + '.' + self.method_name
+
+
+    def adjustedDescription(self, verbosity):
+        if verbosity == 2:
+            return self.method_name
+        elif verbosity > 2:
+            return self.description or self.method_name
+        else:
+            return ''
+
+
 
 class ProtoError():
     """I take a full-fledged test error and preserve just the information we
@@ -64,6 +78,9 @@ class ProtoError():
 
 
 class ProtoTestResult():
+    """
+    I'm the TestResult object for a single unit test run in a subprocess.
+    """
 
 
     def __init__(self):
@@ -158,22 +175,16 @@ class GreenTestResult():
 
     def addProtoTestResult(self, protoTestResult):
         for test, err in protoTestResult.errors:
-            self.startTest(test)
             self.addError(test, err)
         for test, err in protoTestResult.expectedFailures:
-            self.startTest(test)
             self.addExpectedFailure(test, err)
         for test, err in protoTestResult.failures:
-            self.startTest(test)
             self.addFailure(test, err)
         for test in protoTestResult.passing:
-            self.startTest(test)
             self.addSuccess(test)
         for test, reason in protoTestResult.skipped:
-            self.startTest(test)
             self.addSkip(test, reason)
         for test in protoTestResult.unexpectedSuccesses:
-            self.startTest(test)
             self.addUnexpectedSuccess(test)
 
 
@@ -244,13 +255,14 @@ class GreenTestResult():
                 self.stream.writeln(self.colors.className(
                     self.stream.formatText(current_class, indent=1)))
             # Test name or description
-            self.test_output_line = self._testDescription(test)
             if not self.colors.html:
                 # In the terminal, we will write a placeholder, and then
                 # rewrite it in color after the test has run.
                 self.stream.write(
                     self.colors.bold(
-                        self.stream.formatLine(self.test_output_line, indent=2)))
+                        self.stream.formatLine(
+                            test.adjustedDescription(self.verbosity),
+                            indent=2)))
             self.stream.flush()
 
         # Set state for next time
@@ -264,27 +276,21 @@ class GreenTestResult():
         "Called after the end of each test"
 
 
-    def _testDescription(self, test):
-        test = proto_test(test)
-        if self.verbosity == 2:
-            return test.method_name
-        elif self.verbosity > 2:
-            return test.description or test.method_name
-
-
     def _reportOutcome(self, test, outcome_char, color_func, err=None,
             reason=''):
+        test = proto_test(test)
         if self.showAll:
             # Move the cursor back to the start of the line in terminal mode
             if not self.colors.html:
                 self.stream.write('\r')
             # Escape the HTML that may be in the docstring
+            test_description = test.adjustedDescription(self.verbosity)
             if self.colors.html:
-                self.test_output_line = escape(self.test_output_line)
+                test_description = escape(test_description)
             self.stream.write(
                 color_func(
                     self.stream.formatLine(
-                        self.test_output_line,
+                        test_description,
                         indent=2,
                         outcome_char=outcome_char)
                 )
@@ -300,6 +306,7 @@ class GreenTestResult():
 
     def addSuccess(self, test):
         "Called when a test passed"
+        test = proto_test(test)
         self.passing.append(test)
         self._reportOutcome(test, '.', self.colors.passing)
 
